package testcases;

import model.Book;
import model.BookType;
import model.Library;
import model.ModelFactory;

import org.eclipse.emf.cdo.eresource.CDOResource;
import org.eclipse.emf.cdo.net4j.CDONet4jSession;
import org.eclipse.emf.cdo.net4j.CDONet4jSessionConfiguration;
import org.eclipse.emf.cdo.net4j.CDONet4jUtil;
import org.eclipse.emf.cdo.transaction.CDOTransaction;
import org.eclipse.net4j.Net4jUtil;
import org.eclipse.net4j.connector.IConnector;
import org.eclipse.net4j.tcp.TCPUtil;
import org.eclipse.net4j.util.container.IPluginContainer;
import org.eclipse.net4j.util.lifecycle.ILifecycle;
import org.eclipse.net4j.util.lifecycle.LifecycleEventAdapter;
import org.junit.BeforeClass;
import org.junit.Test;

public class CDOTest {

	private static CDONet4jSession cdoSession;

	@BeforeClass
	public static void init() {
		// The following lines are not needed if the extension
		// registry (OSGi/Equinox) is running
		Net4jUtil.prepareContainer(IPluginContainer.INSTANCE);
		TCPUtil.prepareContainer(IPluginContainer.INSTANCE);

		cdoSession = openSession("demo");
	}

	@Test
	public void popola() {
		try {
			CDOTransaction transaction = cdoSession.openTransaction();
			CDOResource resource = transaction.getOrCreateResource("/resource");

			Library lib = ModelFactory.eINSTANCE.createLibrary();
			Book book = ModelFactory.eINSTANCE.createBook();
			Book book2 = ModelFactory.eINSTANCE.createBook();
			lib.getBooks().add(book);
			lib.getBooks().add(book2);
			book.setType(BookType.ELECTRONICAL);

			resource.getContents().add(lib);
			transaction.commit();
			cdoSession.close();
		} catch (Exception e) {

			e.printStackTrace();
		} finally {
			cdoSession.close();
		}
	}

	public static CDONet4jSession openSession(String repoName) {
		final IConnector connector = (IConnector) IPluginContainer.INSTANCE.getElement( //
				"org.eclipse.net4j.connectors", // Product group
				"tcp", // Type
				"localhost"); // Description

		CDONet4jSessionConfiguration config = CDONet4jUtil.createNet4jSessionConfiguration();
		config.setConnector(connector);
		config.setRepositoryName(repoName);

		CDONet4jSession session = config.openNet4jSession();

		session.addListener(new LifecycleEventAdapter() {
			@Override
			protected void onDeactivated(ILifecycle lifecycle) {
				connector.close();
			}
		});

		return session;
	}
}
